@@ -35,7 +35,6 @@ const (
 	CleanJobType              = "clean"
 	FixErrorJobType           = "fix_error"
 	CheckSystemJobType        = "check_system"
-	OfflineUpdateJobType      = "offline_update"
 
 	// UpgradeJobType 创建任务时会根据四种下载和安装类型,分别创建带有不同参数的下载和更新任务
 	PrepareSystemUpgradeJobType   = "prepare_system_upgrade"
@@ -46,7 +45,6 @@ const (
 	AppStoreUpgradeJobType        = "appstore_upgrade"
 	SecurityUpgradeJobType        = "security_upgrade"
 	UnknownUpgradeJobType         = "unknown_upgrade"
-	OfflineUpgradeJobType         = "offline_update"
 	OtherUpgradeJobType           = "other_system_update"
 	AppendUpgradeJobTye           = "append_upgrade"
 
@@ -66,6 +64,8 @@ type JobProgressInfo struct {
 	Cancelable  bool
 	Error       *JobError
 	FatalError  bool
+	OriginalLog string
+	OnlyLog     bool
 }
 
 type UpgradeInfo struct {
