@@ -25,6 +25,7 @@ import (
 	"github.com/linuxdeepin/lastore-daemon/src/internal/config"
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system/apt"
+	"github.com/linuxdeepin/lastore-daemon/src/internal/utils"
 
 	"github.com/godbus/dbus/v5"
 	"github.com/linuxdeepin/go-lib/dbusutil"
@@ -143,6 +144,24 @@ func getLang(envVars procfs.EnvVars) string {
 	return ""
 }
 
+var originalLocaleEnvs []string
+
+// collectAndClearLocaleEnvs collects current locale environment variables,
+// clears them from the environment, and stores the original values for later use
+func collectAndClearLocaleEnvs() {
+	originalLocaleEnvs = nil
+	// Iterate over the list of environment variable names related to locale settings
+	for _, localeEnvName := range []string{"LC_ALL", "LANGUAGE",
+		"LC_MESSAGES", "LANG"} {
+		localeEnvValue, exists := os.LookupEnv(localeEnvName)
+		if exists {
+			// Store the original locale environment variables for later use
+			originalLocaleEnvs = append(originalLocaleEnvs, localeEnvName+"="+localeEnvValue)
+		}
+		_ = utils.UnsetEnv(localeEnvName)
+	}
+}
+
 func listPackageDesktopFiles(pkg string) []string {
 	var result []string
 	filenames := system.ListPackageFile(pkg)
@@ -266,6 +285,7 @@ const (
 	amDaemonCompatPath    = "/usr/libexec/dde-application-wizard-daemon-compat"
 )
 
+// TODO delete
 var (
 	allowInstallPackageExecPaths = strv.Strv{
 		appStoreDaemonPath,
@@ -342,34 +362,6 @@ func getFilterPackages(infosMap map[string][]string, updateType system.UpdateTyp
 	return r
 }
 
-// SystemUpgradeInfo 将update_infos.json数据解析成map TODO 包相关信息已经不在update_infos.json文件中了
-func SystemUpgradeInfo() (map[string][]system.UpgradeInfo, error) {
-	r := make(system.SourceUpgradeInfoMap)
-
-	filename := path.Join(system.VarLibDir, "update_infos.json")
-	var updateInfosList []system.UpgradeInfo
-	err := system.DecodeJson(filename, &updateInfosList)
-	if err != nil {
-		if os.IsNotExist(err) {
-			outputErrorPath := fmt.Sprintf("error_%v", "update_infos.json")
-			filename = path.Join(system.VarLibDir, outputErrorPath)
-			if system.NormalFileExists(filename) {
-				var updateInfoErr system.UpdateInfoError
-				err2 := system.DecodeJson(filename, &updateInfoErr)
-				if err2 == nil {
-					return nil, &updateInfoErr
-				}
-				return nil, fmt.Errorf("Invalid update_infos: %v\n", err)
-			}
-			return nil, err
-		}
-	}
-	for _, info := range updateInfosList {
-		r[info.Category] = append(r[info.Category], info)
-	}
-	return r, nil
-}
-
 func cleanAllCache() {
 	err := exec.Command("apt-get", "clean", "-c", system.LastoreAptV2CommonConfPath).Run()
 	if err != nil {
