@@ -14,7 +14,6 @@ import (
 	. "github.com/linuxdeepin/lastore-daemon/src/internal/config"
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system"
 	"github.com/linuxdeepin/lastore-daemon/src/internal/system/dut"
-	"github.com/linuxdeepin/lastore-daemon/src/internal/utils"
 
 	"github.com/godbus/dbus/v5"
 	"github.com/linuxdeepin/dde-api/inhibit_hint"
@@ -61,10 +60,8 @@ func main() {
 		return
 	}
 
-	_ = utils.UnsetEnv("LC_ALL")
-	_ = utils.UnsetEnv("LANGUAGE")
-	_ = utils.UnsetEnv("LC_MESSAGES")
-	_ = utils.UnsetEnv("LANG")
+	// Collect and clear locale environment variables
+	collectAndClearLocaleEnvs()
 
 	gettext.InitI18n()
 	gettext.Textdomain("lastore-daemon")
@@ -109,9 +106,6 @@ func main() {
 	if err != nil {
 		logger.Error("failed to set write cb for property CheckUpdateMode:", err)
 	}
-	err = serverObject.SetReadCallback(updater, "offlineInfo", func(read *dbusutil.PropertyRead) *dbus.Error {
-		return dbusutil.ToError(updater.SetOfflineInfo(manager.offline.GetCheckInfo()))
-	})
 	// 每次读取SystemSourceConfig和SecuritySourceConfig都实时获取一次配置
 	err = serverObject.SetReadCallback(manager, "systemSourceConfig", func(read *dbusutil.PropertyRead) *dbus.Error {
 		manager.reloadOemConfig(false)
@@ -162,10 +156,6 @@ func main() {
 	service.SetAutoQuitHandler(autoQuitTime, manager.canAutoQuit)
 	service.Wait()
 	manager.saveLastoreCache()
-	err = manager.offline.CleanCache()
-	if err != nil {
-		logger.Warning(err)
-	}
 }
 
 func initLastoreInhibitHint(service *dbusutil.Service) {
