@@ -123,6 +123,11 @@ func (m *Manager) updateSource(sender dbus.Sender) (*Job, error) {
 			handleUpdateSourceFailed(j)
 		}
 		job.setPreHooks(map[string]func() error{
+			string(system.RunningStatus): func() error {
+				// 检查更新需要重置备份状态,主要是处理备份失败后再检查更新,会直接显示失败的场景
+				m.statusManager.SetABStatus(system.AllCheckUpdate, system.NotBackup, system.NoABError)
+				return nil
+			},
 			string(system.SucceedStatus): func() error {
 				m.refreshUpdateInfos(true)
 				m.PropsMu.Lock()
@@ -498,7 +503,7 @@ func (m *Manager) refreshUpdateInfos(sync bool) {
 		go func() {
 			m.inhibitAutoQuitCountAdd()
 			logger.Info("auto download force updates")
-			_, err := m.prepareDistUpgrade(dbus.Sender(m.service.Conn().Names()[0]), system.SystemUpdate, false) // TODO system.SystemUpdate
+			_, err := m.prepareDistUpgrade(dbus.Sender(m.service.Conn().Names()[0]), system.SystemUpdate) // TODO system.SystemUpdate
 			if err != nil {
 				logger.Error("failed to prepare dist-upgrade:", err)
 			}
@@ -522,7 +527,7 @@ func (m *Manager) refreshUpdateInfos(sync bool) {
 		logger.Info("auto download updates")
 		go func() {
 			m.inhibitAutoQuitCountAdd()
-			_, err := m.PrepareDistUpgrade(dbus.Sender(m.service.Conn().Names()[0]))
+			_, err := m.prepareDistUpgrade(dbus.Sender(m.service.Conn().Names()[0]), m.CheckUpdateMode)
 			if err != nil {
 				logger.Error("failed to prepare dist-upgrade:", err)
 			}
