@@ -5,7 +5,6 @@
 package main
 
 import (
-	"bytes"
 	"crypto/sha256"
 	"encoding/hex"
 	"encoding/json"
@@ -13,7 +12,6 @@ import (
 	"fmt"
 	"net/url"
 	"os"
-	"os/exec"
 	"path/filepath"
 	"strings"
 	"sync"
@@ -44,18 +42,15 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 	var startJobErr error
 	var mode system.UpdateType
 	// 非离线安装需要过滤可更新的选项
-	if origin&system.OfflineUpdate == 0 {
-		mode = m.statusManager.GetCanDistUpgradeMode(origin) // 正在安装的状态会包含其中,会在创建job中找到对应job(由于不追加安装,因此直接返回之前的job)
-		if mode == 0 {
-			return "", dbusutil.ToError(errors.New("don't exist can distUpgrade mode"))
-		}
-	} else {
-		mode = origin
+	mode = m.statusManager.GetCanDistUpgradeMode(origin) // 正在安装的状态会包含其中,会在创建job中找到对应job(由于不追加安装,因此直接返回之前的job)
+	if mode == 0 {
+		return "", dbusutil.ToError(errors.New("don't exist can distUpgrade mode"))
 	}
+
 	if updateplatform.IsForceUpdate(m.updatePlatform.Tp) {
 		mode = origin
 	}
-	upgradeJob, createJobErr = m.distUpgrade(sender, mode, false, false, false)
+	upgradeJob, createJobErr = m.distUpgrade(sender, mode, false, false)
 	if createJobErr != nil {
 		if !errors.Is(createJobErr, JobExistError) {
 			return "/", dbusutil.ToError(createJobErr)
@@ -138,6 +133,14 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 		backupJob.next = upgradeJob
 		backupJob.setPreHooks(map[string]func() error{
 			string(system.RunningStatus): func() error {
+				// 每次开始更新前，清理之前记录的日志文件
+				_ = os.RemoveAll(logTmpPath)
+				_ = m.logTmpFile.Close()
+				m.logTmpFile = nil
+				m.logTmpFile, err = os.OpenFile(logTmpPath, os.O_CREATE|os.O_WRONLY|os.O_APPEND, 0644)
+				if err != nil {
+					return fmt.Errorf("failed to open file %s: %v", logTmpPath, err)
+				}
 				inhibit(true)
 				m.statusManager.SetABStatus(mode, system.BackingUp, system.NoABError)
 				return nil
@@ -195,9 +198,8 @@ func (m *Manager) distUpgradePartly(sender dbus.Sender, origin system.UpdateType
 	return upgradeJob.getPath(), nil
 }
 
-// distUpgrade isClassify true: mode只能是单类型,创建一个单类型的更新job; false: mode类型不限,创建一个全mode类型的更新job
-// needAdd true: 返回的job已经被add到jobManager中；false: 返回的job需要被调用者add
-func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, isClassify bool, needAdd bool, needChangeGrub bool) (*Job, error) {
+// distUpgrade needAdd true: 返回的job已经被add到jobManager中；false: 返回的job需要被调用者add
+func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, needAdd bool, needChangeGrub bool) (*Job, error) {
 	m.checkDpkgCapabilityOnce.Do(func() {
 		m.supportDpkgScriptIgnore = checkSupportDpkgScriptIgnore()
 	})
@@ -218,16 +220,9 @@ func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, isClas
 	m.updateJobList()
 	var packages []string
 
-	// 判断是否有可离线更新内容
-	if mode == system.OfflineUpdate {
-		if len(m.offline.upgradeAblePackageList) == 0 {
-			return nil, system.NotFoundError(fmt.Sprintf("empty %v UpgradableApps", mode))
-		}
-	} else {
-		packages = m.updater.getUpdatablePackagesByType(mode)
-		if len(packages) == 0 {
-			return nil, system.NotFoundError(fmt.Sprintf("empty %v UpgradableApps", mode))
-		}
+	packages = m.updater.getUpdatablePackagesByType(mode)
+	if len(packages) == 0 {
+		return nil, system.NotFoundError(fmt.Sprintf("empty %v UpgradableApps", mode))
 	}
 
 	var isExist bool
@@ -245,10 +240,7 @@ func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, isClas
 	err = system.CustomSourceWrapper(mergeMode, func(path string, unref func()) error {
 		m.do.Lock()
 		defer m.do.Unlock()
-		if isClassify {
-			jobType := GetUpgradeInfoMap()[mode].UpgradeJobId
-			isExist, job, err = m.jobManager.CreateJob("", jobType, nil, environ, nil)
-		} else {
+		{
 			option := map[string]interface{}{
 				"UpdateMode":              mode, // 原始mode
 				"SupportDpkgScriptIgnore": m.supportDpkgScriptIgnore,
@@ -280,10 +272,6 @@ func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, isClas
 			}
 		}
 
-		if mode == system.OfflineUpdate {
-			job.option["Dir::State::lists"] = system.OfflineListPath
-		}
-
 		if m.supportDpkgScriptIgnore && mode == system.UnknownUpdate {
 			job.option["DPkg::Options::"] = "--script-ignore-error"
 		}
@@ -313,7 +301,7 @@ func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, isClas
 				}
 				logger.Info(uuid)
 				m.updatePlatform.CreateJobPostMsgInfo(uuid, job.updateTyp)
-				systemErr := dut.CheckSystem(dut.PreCheck, mode == system.OfflineUpdate, nil) // 只是为了执行precheck的hook脚本
+				systemErr := dut.CheckSystem(dut.PreCheck, nil) // 只是为了执行precheck的hook脚本
 				if systemErr != nil {
 					logger.Info(systemErr)
 					m.updatePlatform.PostStatusMessage(fmt.Sprintf("%v CheckSystem failed, detail is: %v", mode.JobType(), systemErr.Error()))
@@ -337,14 +325,14 @@ func (m *Manager) distUpgrade(sender dbus.Sender, mode system.UpdateType, isClas
 
 		endJob.setPreHooks(map[string]func() error{
 			string(system.SucceedStatus): func() error {
-				systemErr := dut.CheckSystem(dut.MidCheck, mode == system.OfflineUpdate, nil)
+				systemErr := dut.CheckSystem(dut.MidCheck, nil)
 				if systemErr != nil {
 					logger.Info(systemErr)
 					m.updatePlatform.PostStatusMessage(fmt.Sprintf("%v CheckSystem failed, detail is: %v", mode.JobType(), systemErr.Error()))
 					return systemErr
 				}
 				if m.statusManager.abStatus == system.HasBackedUp {
-					if err := osTreeRefresh(); err != nil {
+					if err := m.immutableManager.osTreeRefresh(); err != nil {
 						logger.Warning("ostree deploy refresh failed,", err)
 					}
 				}
@@ -545,147 +533,6 @@ func (m *Manager) preFailedHook(job *Job, mode system.UpdateType, uuid string) e
 	return nil
 }
 
-// 格式化输出需要添加-j 参数
-func osTreeCmd(args []string) (out string, err error) {
-	if system.NormalFileExists(DEEPIN_IMMUTABLE_CTL) {
-		args = append(args, "-v")
-		cmd := exec.Command(DEEPIN_IMMUTABLE_CTL, args...) // #nosec G204
-		cmd.Env = append(os.Environ(), "IMMUTABLE_DISABLE_REMOUNT=false")
-		logger.Info("run command:", cmd.Args)
-		var stdout, stderr bytes.Buffer
-		cmd.Stdout = &stdout
-		cmd.Stderr = &stderr
-		ff, err := system.OpenFlush(system.FlushName)
-		if err == nil {
-			defer func() {
-				ff.WriteString(fmt.Sprintf("=== Ostree %v end ===\n", cmd.Args))
-				ff.Close()
-			}()
-
-			err = ff.SetFlushCmd(cmd)
-			if err != nil {
-				logger.Warning(err)
-			}
-		}
-		ff.WriteString(fmt.Sprintf("=== Ostree cmd running: %v ===\n", cmd.Args))
-		err = cmd.Run()
-		if err != nil {
-			return "", fmt.Errorf("%v", stderr.String())
-		} else {
-			return stdout.String(), nil
-		}
-	} else {
-		return "", fmt.Errorf("%v not found", DEEPIN_IMMUTABLE_CTL)
-	}
-}
-
-type ostreeError struct {
-	Code    string   `json:"code"`
-	Message []string `json:"message"`
-}
-
-type ostreeRollbackData struct {
-	Version     int    `json:"version"`
-	CanRollback bool   `json:"can_rollback"`
-	Time        int64  `json:"time"`
-	Name        string `json:"name"`
-	Auto        bool   `json:"auto"`
-	Reboot      bool   `json:"reboot"`
-}
-
-type ostreeResponse struct {
-	Code    uint8           `json:"code"`
-	Message string          `json:"message"`
-	Error   *ostreeError    `json:"error"`
-	Data    json.RawMessage `json:"data"`
-}
-
-func osTreeRefresh() error {
-	_, err := osTreeCmd([]string{"admin", "deploy", "--refresh"})
-	if err != nil {
-		return err
-	}
-	return nil
-}
-
-func osTreeFinalize() error {
-	_, err := osTreeCmd([]string{"admin", "deploy", "--finalize"})
-	if err != nil {
-		return err
-	}
-	return nil
-}
-
-func osTreeRollback() error {
-	_, err := osTreeCmd([]string{"admin", "rollback"})
-	if err != nil {
-		return err
-	}
-	return nil
-}
-
-func osTreeParseRollbackData() (string, error) {
-	out, err := osTreeCmd([]string{"admin", "rollback", "--can-rollback", "-j"})
-	if err != nil {
-		logger.Warning("osTreeCmd failed:", err)
-		return "", err
-	}
-
-	logger.Info("osTree rollback output:", out)
-
-	var resp ostreeResponse
-	err = json.Unmarshal([]byte(out), &resp)
-	if err != nil {
-		logger.Warning("unmarshal ostree response failed:", err)
-		return "", err
-	}
-
-	if resp.Error != nil {
-		logger.Warning("ostree response has error:", resp.Error)
-		return "", fmt.Errorf("ostree error: %v", resp.Error)
-	}
-
-	return string(resp.Data), nil
-}
-
-func osTreeCanRollback() (bool, string) {
-	dataJson, err := osTreeParseRollbackData()
-	if err != nil {
-		return false, ""
-	}
-
-	var data ostreeRollbackData
-	err = json.Unmarshal([]byte(dataJson), &data)
-	if err != nil {
-		return false, ""
-	}
-
-	return data.CanRollback, dataJson
-}
-
-func osTreeNeedRebootAfterRollback() bool {
-	dataJson, err := osTreeParseRollbackData()
-	if err != nil {
-		return false
-	}
-
-	var data ostreeRollbackData
-	err = json.Unmarshal([]byte(dataJson), &data)
-	if err != nil {
-		return false
-	}
-
-	// 兼容旧版本，Auto为true时，表示不需要重启
-	var rawData map[string]json.RawMessage
-	if err := json.Unmarshal([]byte(dataJson), &rawData); err == nil {
-		if _, hasReboot := rawData["reboot"]; !hasReboot {
-			return !data.Auto
-		}
-	}
-
-	return data.Reboot
-}
-
 func (m *Manager) preUpgradeCmdSuccessHook(job *Job, needChangeGrub bool, mode system.UpdateType, uuid string) error {
 	if !m.config.GetPlatformStatusDisable(config.DisabledRebootCheck) {
 		// 设置重启后的检查项;重启后需要检查时,需要将本次job的uuid记录到检查配置中,无需检查时只要将uuid直接记录到 upgradeJobMetaInfo 中即可
@@ -751,48 +598,12 @@ func (m *Manager) cancelAllUpdateJob() error {
 	return nil
 }
 
-func onlyDownloadOfflinePackage(pkgsMap map[string]system.PackageInfo) error {
-	var packages []string
-	for _, info := range pkgsMap {
-		packages = append(packages, fmt.Sprintf("%v=%v", info.Name, info.Version))
-	}
-	cmdStr := fmt.Sprintf("apt-get download %v -c /var/lib/lastore/apt_v2_common.conf --allow-change-held-packages -o Dir::State::lists=/var/lib/lastore/offline_list -o Dir::Etc::SourceParts=/dev/null -o Dir::Etc::SourceList=/var/lib/lastore/offline.list", strings.Join(packages, " "))
-	cmd := exec.Command("/bin/sh", "-c", cmdStr)
-	cmd.Dir = system.LocalCachePath // 该路径和/var/lib/lastore/apt_v2_common.conf保持一致
-	var outBuf bytes.Buffer
-	cmd.Stdout = &outBuf
-	var errBuf bytes.Buffer
-	cmd.Stderr = &errBuf
-	err := cmd.Run()
-	if err != nil {
-		logger.Info(err)
-		logger.Info(errBuf.String())
-		return err
-	}
-	return nil
-}
-
 // 生成meta.json和uuid 暂时不使用dut，使用apt
 func (m *Manager) prepareDutUpgrade(job *Job, mode system.UpdateType) (string, error) {
 	// 使用dut更新前的准备
 	var uuid string
 	var err error
-	if mode == system.OfflineUpdate {
-		// 转移包路径
-		err = onlyDownloadOfflinePackage(m.offline.upgradeAblePackages)
-		if err != nil {
-			return "", err
-		}
-		job.option["--meta-cfg"] = system.DutOfflineMetaConfPath
-		uuid, err = dut.GenDutMetaFile(system.DutOfflineMetaConfPath,
-			system.LocalCachePath,
-			m.offline.upgradeAblePackages,
-			m.offline.upgradeAblePackages, nil, m.offline.upgradeAblePackages, m.offline.removePackages, nil, genRepoInfo(mode, system.OfflineListPath))
-		if err != nil {
-			logger.Warning(err)
-			return "", err
-		}
-	} else {
+	{
 		job.option["--meta-cfg"] = system.DutOnlineMetaConfPath
 		var pkgMap map[string]system.PackageInfo
 		var removeMap map[string]system.PackageInfo
@@ -861,11 +672,8 @@ func (m *Manager) prepareAptCheck(mode system.UpdateType) (string, error) {
 	// pkgMap repo和system.LocalCachePath都是占位用，没有起到真正的作用
 	pkgMap := make(map[string]system.PackageInfo)
 	var repo []dut.RepoInfo
-	if mode == system.OfflineUpdate {
-		repo = genRepoInfo(system.OfflineUpdate, system.OfflineListPath)
-	} else {
-		repo = genRepoInfo(mode, system.OnlineListPath)
-	}
+
+	repo = genRepoInfo(mode, system.OnlineListPath)
 
 	// coreList 生成
 	coreListMap := make(map[string]system.PackageInfo)
@@ -901,20 +709,7 @@ func (m *Manager) prepareAptCheck(mode system.UpdateType) (string, error) {
 		coreListMap = loadCoreList()
 	}
 	// 使用dut检查前的准备
-	if mode == system.OfflineUpdate {
-		uuid, err = dut.GenDutMetaFile(system.DutOfflineMetaConfPath,
-			system.LocalCachePath,
-			pkgMap,
-			coreListMap, nil, nil, nil, nil, repo)
-		if err != nil {
-			logger.Warning(err)
-			return "", &system.JobError{
-				ErrType:      system.ErrorUnknown,
-				ErrDetail:    err.Error(),
-				IsCheckError: true,
-			}
-		}
-	} else {
+	{
 		mode &= system.AllInstallUpdate
 		if mode == 0 {
 			return "", errors.New("invalid mode")
@@ -1003,9 +798,6 @@ func getPackagesPathList(typ system.UpdateType, listPath string) []string {
 	if typ&system.SecurityUpdate != 0 {
 		urls = append(urls, getUpgradeUrls(system.GetCategorySourceMap()[system.SecurityUpdate])...)
 	}
-	if typ&system.OfflineUpdate != 0 {
-		urls = append(urls, getUpgradeUrls(system.GetCategorySourceMap()[system.OfflineUpdate])...)
-	}
 	if typ&system.UnknownUpdate != 0 {
 		urls = append(urls, getUpgradeUrls(system.GetCategorySourceMap()[system.UnknownUpdate])...)
 	}
